@@ -1,44 +1,16 @@
-#![allow(
-    unused_variables,
-    non_upper_case_globals,
-    non_snake_case,
-    unused_unsafe,
-    non_camel_case_types,
-    dead_code,
-    clippy::all
-)]
-pub const CLSID_DeviceIoControl: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(
-    315876210,
-    34635,
-    17789,
-    [159, 223, 115, 151, 119, 120, 104, 108],
-);
+#![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
+pub const CLSID_DeviceIoControl: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(315876210, 34635, 17789, [159, 223, 115, 151, 119, 120, 104, 108]);
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn CreateDeviceAccessInstance<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
->(
-    deviceinterfacepath: Param0,
-    desiredaccess: u32,
-) -> ::windows::runtime::Result<ICreateDeviceAccessAsync> {
+#[inline]
+pub unsafe fn CreateDeviceAccessInstance<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>>(deviceinterfacepath: Param0, desiredaccess: u32) -> ::windows::runtime::Result<ICreateDeviceAccessAsync> {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn CreateDeviceAccessInstance(
-                deviceinterfacepath: super::super::Foundation::PWSTR,
-                desiredaccess: u32,
-                createasync: *mut ::windows::runtime::RawPtr,
-            ) -> ::windows::runtime::HRESULT;
+            fn CreateDeviceAccessInstance(deviceinterfacepath: super::super::Foundation::PWSTR, desiredaccess: u32, createasync: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT;
         }
-        let mut result__: <ICreateDeviceAccessAsync as ::windows::runtime::Abi>::Abi =
-            ::std::mem::zeroed();
-        CreateDeviceAccessInstance(
-            deviceinterfacepath.into_param().abi(),
-            ::std::mem::transmute(desiredaccess),
-            &mut result__,
-        )
-        .from_abi::<ICreateDeviceAccessAsync>(result__)
+        let mut result__: <ICreateDeviceAccessAsync as ::windows::runtime::Abi>::Abi = ::std::mem::zeroed();
+        CreateDeviceAccessInstance(deviceinterfacepath.into_param().abi(), ::std::mem::transmute(desiredaccess), &mut result__).from_abi::<ICreateDeviceAccessAsync>(result__)
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
@@ -88,47 +60,26 @@ pub const ED_RIGHT: u32 = 1024u32;
 pub const ED_TOP: u32 = 1u32;
 pub const ED_VIDEO: i32 = 33554432i32;
 #[repr(transparent)]
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: clone :: Clone,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: clone :: Clone, :: std :: fmt :: Debug)]
 pub struct ICreateDeviceAccessAsync(::windows::runtime::IUnknown);
 impl ICreateDeviceAccessAsync {
     pub unsafe fn Cancel(&self) -> ::windows::runtime::Result<()> {
         (::windows::runtime::Interface::vtable(self).3)(::std::mem::transmute_copy(self)).ok()
     }
     pub unsafe fn Wait(&self, timeout: u32) -> ::windows::runtime::Result<()> {
-        (::windows::runtime::Interface::vtable(self).4)(
-            ::std::mem::transmute_copy(self),
-            ::std::mem::transmute(timeout),
-        )
-        .ok()
+        (::windows::runtime::Interface::vtable(self).4)(::std::mem::transmute_copy(self), ::std::mem::transmute(timeout)).ok()
     }
     pub unsafe fn Close(&self) -> ::windows::runtime::Result<()> {
         (::windows::runtime::Interface::vtable(self).5)(::std::mem::transmute_copy(self)).ok()
     }
-    pub unsafe fn GetResult<T: ::windows::runtime::Interface>(
-        &self,
-    ) -> ::windows::runtime::Result<T> {
+    pub unsafe fn GetResult<T: ::windows::runtime::Interface>(&self) -> ::windows::runtime::Result<T> {
         let mut result__ = ::std::option::Option::None;
-        (::windows::runtime::Interface::vtable(self).6)(
-            ::std::mem::transmute_copy(self),
-            &<T as ::windows::runtime::Interface>::IID,
-            &mut result__ as *mut _ as *mut _,
-        )
-        .and_some(result__)
+        (::windows::runtime::Interface::vtable(self).6)(::std::mem::transmute_copy(self), &<T as ::windows::runtime::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
     }
 }
 unsafe impl ::windows::runtime::Interface for ICreateDeviceAccessAsync {
     type Vtable = ICreateDeviceAccessAsync_abi;
-    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(
-        880042639,
-        26685,
-        17106,
-        [171, 203, 219, 1, 140, 101, 3, 188],
-    );
+    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(880042639, 26685, 17106, [171, 203, 219, 1, 140, 101, 3, 188]);
 }
 impl ::std::convert::From<ICreateDeviceAccessAsync> for ::windows::runtime::IUnknown {
     fn from(value: ICreateDeviceAccessAsync) -> Self {
@@ -140,90 +91,35 @@ impl ::std::convert::From<&ICreateDeviceAccessAsync> for ::windows::runtime::IUn
         ::std::convert::From::from(::std::clone::Clone::clone(value))
     }
 }
-impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown>
-    for ICreateDeviceAccessAsync
-{
+impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for ICreateDeviceAccessAsync {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(self),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(self))
     }
 }
-impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown>
-    for &ICreateDeviceAccessAsync
-{
+impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &ICreateDeviceAccessAsync {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(
-                self,
-            )),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(self)))
     }
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct ICreateDeviceAccessAsync_abi(
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        iid: &::windows::runtime::GUID,
-        interface: *mut ::windows::runtime::RawPtr,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        timeout: u32,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, timeout: u32) -> ::windows::runtime::HRESULT,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        riid: *const ::windows::runtime::GUID,
-        deviceaccess: *mut *mut ::std::ffi::c_void,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, riid: *const ::windows::runtime::GUID, deviceaccess: *mut *mut ::std::ffi::c_void) -> ::windows::runtime::HRESULT,
 );
 #[repr(transparent)]
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: clone :: Clone,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: clone :: Clone, :: std :: fmt :: Debug)]
 pub struct IDeviceIoControl(::windows::runtime::IUnknown);
 impl IDeviceIoControl {
-    pub unsafe fn DeviceIoControlSync(
-        &self,
-        iocontrolcode: u32,
-        inputbuffer: *const u8,
-        inputbuffersize: u32,
-        outputbuffer: *mut u8,
-        outputbuffersize: u32,
-        bytesreturned: *mut u32,
-    ) -> ::windows::runtime::Result<()> {
-        (::windows::runtime::Interface::vtable(self).3)(
-            ::std::mem::transmute_copy(self),
-            ::std::mem::transmute(iocontrolcode),
-            ::std::mem::transmute(inputbuffer),
-            ::std::mem::transmute(inputbuffersize),
-            ::std::mem::transmute(outputbuffer),
-            ::std::mem::transmute(outputbuffersize),
-            ::std::mem::transmute(bytesreturned),
-        )
-        .ok()
+    pub unsafe fn DeviceIoControlSync(&self, iocontrolcode: u32, inputbuffer: *const u8, inputbuffersize: u32, outputbuffer: *mut u8, outputbuffersize: u32, bytesreturned: *mut u32) -> ::windows::runtime::Result<()> {
+        (::windows::runtime::Interface::vtable(self).3)(::std::mem::transmute_copy(self), ::std::mem::transmute(iocontrolcode), ::std::mem::transmute(inputbuffer), ::std::mem::transmute(inputbuffersize), ::std::mem::transmute(outputbuffer), ::std::mem::transmute(outputbuffersize), ::std::mem::transmute(bytesreturned)).ok()
     }
-    pub unsafe fn DeviceIoControlAsync<
-        'a,
-        Param5: ::windows::runtime::IntoParam<'a, IDeviceRequestCompletionCallback>,
-    >(
-        &self,
-        iocontrolcode: u32,
-        inputbuffer: *const u8,
-        inputbuffersize: u32,
-        outputbuffer: *mut u8,
-        outputbuffersize: u32,
-        requestcompletioncallback: Param5,
-        cancelcontext: *mut usize,
-    ) -> ::windows::runtime::Result<()> {
+    pub unsafe fn DeviceIoControlAsync<'a, Param5: ::windows::runtime::IntoParam<'a, IDeviceRequestCompletionCallback>>(&self, iocontrolcode: u32, inputbuffer: *const u8, inputbuffersize: u32, outputbuffer: *mut u8, outputbuffersize: u32, requestcompletioncallback: Param5, cancelcontext: *mut usize) -> ::windows::runtime::Result<()> {
         (::windows::runtime::Interface::vtable(self).4)(
             ::std::mem::transmute_copy(self),
             ::std::mem::transmute(iocontrolcode),
@@ -237,21 +133,12 @@ impl IDeviceIoControl {
         .ok()
     }
     pub unsafe fn CancelOperation(&self, cancelcontext: usize) -> ::windows::runtime::Result<()> {
-        (::windows::runtime::Interface::vtable(self).5)(
-            ::std::mem::transmute_copy(self),
-            ::std::mem::transmute(cancelcontext),
-        )
-        .ok()
+        (::windows::runtime::Interface::vtable(self).5)(::std::mem::transmute_copy(self), ::std::mem::transmute(cancelcontext)).ok()
     }
 }
 unsafe impl ::windows::runtime::Interface for IDeviceIoControl {
     type Vtable = IDeviceIoControl_abi;
-    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(
-        2666520929,
-        9131,
-        20248,
-        [155, 73, 153, 27, 88, 106, 233, 112],
-    );
+    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(2666520929, 9131, 20248, [155, 73, 153, 27, 88, 106, 233, 112]);
 }
 impl ::std::convert::From<IDeviceIoControl> for ::windows::runtime::IUnknown {
     fn from(value: IDeviceIoControl) -> Self {
@@ -265,84 +152,35 @@ impl ::std::convert::From<&IDeviceIoControl> for ::windows::runtime::IUnknown {
 }
 impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for IDeviceIoControl {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(self),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(self))
     }
 }
 impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &IDeviceIoControl {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(
-                self,
-            )),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(self)))
     }
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IDeviceIoControl_abi(
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        iid: &::windows::runtime::GUID,
-        interface: *mut ::windows::runtime::RawPtr,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        iocontrolcode: u32,
-        inputbuffer: *const u8,
-        inputbuffersize: u32,
-        outputbuffer: *mut u8,
-        outputbuffersize: u32,
-        bytesreturned: *mut u32,
-    ) -> ::windows::runtime::HRESULT,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        iocontrolcode: u32,
-        inputbuffer: *const u8,
-        inputbuffersize: u32,
-        outputbuffer: *mut u8,
-        outputbuffersize: u32,
-        requestcompletioncallback: ::windows::runtime::RawPtr,
-        cancelcontext: *mut usize,
-    ) -> ::windows::runtime::HRESULT,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        cancelcontext: usize,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iocontrolcode: u32, inputbuffer: *const u8, inputbuffersize: u32, outputbuffer: *mut u8, outputbuffersize: u32, bytesreturned: *mut u32) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iocontrolcode: u32, inputbuffer: *const u8, inputbuffersize: u32, outputbuffer: *mut u8, outputbuffersize: u32, requestcompletioncallback: ::windows::runtime::RawPtr, cancelcontext: *mut usize) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, cancelcontext: usize) -> ::windows::runtime::HRESULT,
 );
 #[repr(transparent)]
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: clone :: Clone,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: clone :: Clone, :: std :: fmt :: Debug)]
 pub struct IDeviceRequestCompletionCallback(::windows::runtime::IUnknown);
 impl IDeviceRequestCompletionCallback {
-    pub unsafe fn Invoke(
-        &self,
-        requestresult: ::windows::runtime::HRESULT,
-        bytesreturned: u32,
-    ) -> ::windows::runtime::Result<()> {
-        (::windows::runtime::Interface::vtable(self).3)(
-            ::std::mem::transmute_copy(self),
-            ::std::mem::transmute(requestresult),
-            ::std::mem::transmute(bytesreturned),
-        )
-        .ok()
+    pub unsafe fn Invoke(&self, requestresult: ::windows::runtime::HRESULT, bytesreturned: u32) -> ::windows::runtime::Result<()> {
+        (::windows::runtime::Interface::vtable(self).3)(::std::mem::transmute_copy(self), ::std::mem::transmute(requestresult), ::std::mem::transmute(bytesreturned)).ok()
     }
 }
 unsafe impl ::windows::runtime::Interface for IDeviceRequestCompletionCallback {
     type Vtable = IDeviceRequestCompletionCallback_abi;
-    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(
-        2577116452,
-        39629,
-        17851,
-        [134, 105, 42, 47, 192, 40, 139, 4],
-    );
+    const IID: ::windows::runtime::GUID = ::windows::runtime::GUID::from_values(2577116452, 39629, 17851, [134, 105, 42, 47, 192, 40, 139, 4]);
 }
 impl ::std::convert::From<IDeviceRequestCompletionCallback> for ::windows::runtime::IUnknown {
     fn from(value: IDeviceRequestCompletionCallback) -> Self {
@@ -354,39 +192,21 @@ impl ::std::convert::From<&IDeviceRequestCompletionCallback> for ::windows::runt
         ::std::convert::From::from(::std::clone::Clone::clone(value))
     }
 }
-impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown>
-    for IDeviceRequestCompletionCallback
-{
+impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for IDeviceRequestCompletionCallback {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(self),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(self))
     }
 }
-impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown>
-    for &IDeviceRequestCompletionCallback
-{
+impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &IDeviceRequestCompletionCallback {
     fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-        ::windows::runtime::Param::Owned(
-            ::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(
-                self,
-            )),
-        )
+        ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(self)))
     }
 }
 #[repr(C)]
 #[doc(hidden)]
 pub struct IDeviceRequestCompletionCallback_abi(
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        iid: &::windows::runtime::GUID,
-        interface: *mut ::windows::runtime::RawPtr,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
     pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
-    pub  unsafe extern "system" fn(
-        this: ::windows::runtime::RawPtr,
-        requestresult: ::windows::runtime::HRESULT,
-        bytesreturned: u32,
-    ) -> ::windows::runtime::HRESULT,
+    pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, requestresult: ::windows::runtime::HRESULT, bytesreturned: u32) -> ::windows::runtime::HRESULT,
 );
