@@ -1,124 +1,106 @@
-#![allow(
-    unused_variables,
-    non_upper_case_globals,
-    non_snake_case,
-    unused_unsafe,
-    non_camel_case_types,
-    dead_code,
-    clippy::all
-)]
+#![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
 #[derive(:: std :: clone :: Clone, :: std :: marker :: Copy)]
 #[repr(C)]
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 pub struct CYPHER_BLOCK {
-    pub data: [super::SystemServices::CHAR; 8],
+    pub data: [super::super::Foundation::CHAR; 8],
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl CYPHER_BLOCK {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::default::Default for CYPHER_BLOCK {
     fn default() -> Self {
         unsafe { ::std::mem::zeroed() }
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::fmt::Debug for CYPHER_BLOCK {
     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-        fmt.debug_struct("CYPHER_BLOCK")
-            .field("data", &self.data)
-            .finish()
+        fmt.debug_struct("CYPHER_BLOCK").field("data", &self.data).finish()
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::PartialEq for CYPHER_BLOCK {
     fn eq(&self, other: &Self) -> bool {
         self.data == other.data
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::Eq for CYPHER_BLOCK {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 unsafe impl ::windows::runtime::Abi for CYPHER_BLOCK {
     type Abi = Self;
     type DefaultType = Self;
 }
 #[derive(:: std :: clone :: Clone, :: std :: marker :: Copy)]
 #[repr(C)]
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 pub struct ENCRYPTED_LM_OWF_PASSWORD {
     pub data: [CYPHER_BLOCK; 2],
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ENCRYPTED_LM_OWF_PASSWORD {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::default::Default for ENCRYPTED_LM_OWF_PASSWORD {
     fn default() -> Self {
         unsafe { ::std::mem::zeroed() }
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::fmt::Debug for ENCRYPTED_LM_OWF_PASSWORD {
     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-        fmt.debug_struct("ENCRYPTED_LM_OWF_PASSWORD")
-            .field("data", &self.data)
-            .finish()
+        fmt.debug_struct("ENCRYPTED_LM_OWF_PASSWORD").field("data", &self.data).finish()
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::PartialEq for ENCRYPTED_LM_OWF_PASSWORD {
     fn eq(&self, other: &Self) -> bool {
         self.data == other.data
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::Eq for ENCRYPTED_LM_OWF_PASSWORD {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 unsafe impl ::windows::runtime::Abi for ENCRYPTED_LM_OWF_PASSWORD {
     type Abi = Self;
     type DefaultType = Self;
 }
 #[derive(:: std :: clone :: Clone, :: std :: marker :: Copy)]
 #[repr(C)]
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 pub struct LM_OWF_PASSWORD {
     pub data: [CYPHER_BLOCK; 2],
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl LM_OWF_PASSWORD {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::default::Default for LM_OWF_PASSWORD {
     fn default() -> Self {
         unsafe { ::std::mem::zeroed() }
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::fmt::Debug for LM_OWF_PASSWORD {
     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-        fmt.debug_struct("LM_OWF_PASSWORD")
-            .field("data", &self.data)
-            .finish()
+        fmt.debug_struct("LM_OWF_PASSWORD").field("data", &self.data).finish()
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::PartialEq for LM_OWF_PASSWORD {
     fn eq(&self, other: &Self) -> bool {
         self.data == other.data
     }
 }
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 impl ::std::cmp::Eq for LM_OWF_PASSWORD {}
-#[cfg(feature = "Win32_System_SystemServices")]
+#[cfg(feature = "Win32_Foundation")]
 unsafe impl ::windows::runtime::Abi for LM_OWF_PASSWORD {
     type Abi = Self;
     type DefaultType = Self;
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_SystemServices"))]
-pub unsafe fn MSChapSrvChangePassword<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>,
->(
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn MSChapSrvChangePassword<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param2: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>>(
     servername: Param0,
     username: Param1,
     lmoldpresent: Param2,
@@ -131,36 +113,16 @@ pub unsafe fn MSChapSrvChangePassword<
     {
         #[link(name = "windows")]
         extern "system" {
-            fn MSChapSrvChangePassword(
-                servername: super::super::Foundation::PWSTR,
-                username: super::super::Foundation::PWSTR,
-                lmoldpresent: super::super::Foundation::BOOLEAN,
-                lmoldowfpassword: *const LM_OWF_PASSWORD,
-                lmnewowfpassword: *const LM_OWF_PASSWORD,
-                ntoldowfpassword: *const LM_OWF_PASSWORD,
-                ntnewowfpassword: *const LM_OWF_PASSWORD,
-            ) -> u32;
+            fn MSChapSrvChangePassword(servername: super::super::Foundation::PWSTR, username: super::super::Foundation::PWSTR, lmoldpresent: super::super::Foundation::BOOLEAN, lmoldowfpassword: *const LM_OWF_PASSWORD, lmnewowfpassword: *const LM_OWF_PASSWORD, ntoldowfpassword: *const LM_OWF_PASSWORD, ntnewowfpassword: *const LM_OWF_PASSWORD) -> u32;
         }
-        ::std::mem::transmute(MSChapSrvChangePassword(
-            servername.into_param().abi(),
-            username.into_param().abi(),
-            lmoldpresent.into_param().abi(),
-            ::std::mem::transmute(lmoldowfpassword),
-            ::std::mem::transmute(lmnewowfpassword),
-            ::std::mem::transmute(ntoldowfpassword),
-            ::std::mem::transmute(ntnewowfpassword),
-        ))
+        ::std::mem::transmute(MSChapSrvChangePassword(servername.into_param().abi(), username.into_param().abi(), lmoldpresent.into_param().abi(), ::std::mem::transmute(lmoldowfpassword), ::std::mem::transmute(lmnewowfpassword), ::std::mem::transmute(ntoldowfpassword), ::std::mem::transmute(ntnewowfpassword)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_SystemServices"))]
-pub unsafe fn MSChapSrvChangePassword2<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>,
->(
+#[cfg(feature = "Win32_Foundation")]
+#[inline]
+pub unsafe fn MSChapSrvChangePassword2<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>>(
     servername: Param0,
     username: Param1,
     newpasswordencryptedwitholdnt: *const SAMPR_ENCRYPTED_USER_PASSWORD,
@@ -173,15 +135,7 @@ pub unsafe fn MSChapSrvChangePassword2<
     {
         #[link(name = "windows")]
         extern "system" {
-            fn MSChapSrvChangePassword2(
-                servername: super::super::Foundation::PWSTR,
-                username: super::super::Foundation::PWSTR,
-                newpasswordencryptedwitholdnt: *const SAMPR_ENCRYPTED_USER_PASSWORD,
-                oldntowfpasswordencryptedwithnewnt: *const ENCRYPTED_LM_OWF_PASSWORD,
-                lmpresent: super::super::Foundation::BOOLEAN,
-                newpasswordencryptedwitholdlm: *const SAMPR_ENCRYPTED_USER_PASSWORD,
-                oldlmowfpasswordencryptedwithnewlmornt: *const ENCRYPTED_LM_OWF_PASSWORD,
-            ) -> u32;
+            fn MSChapSrvChangePassword2(servername: super::super::Foundation::PWSTR, username: super::super::Foundation::PWSTR, newpasswordencryptedwitholdnt: *const SAMPR_ENCRYPTED_USER_PASSWORD, oldntowfpasswordencryptedwithnewnt: *const ENCRYPTED_LM_OWF_PASSWORD, lmpresent: super::super::Foundation::BOOLEAN, newpasswordencryptedwitholdlm: *const SAMPR_ENCRYPTED_USER_PASSWORD, oldlmowfpasswordencryptedwithnewlmornt: *const ENCRYPTED_LM_OWF_PASSWORD) -> u32;
         }
         ::std::mem::transmute(MSChapSrvChangePassword2(
             servername.into_param().abi(),
@@ -209,9 +163,7 @@ impl ::std::default::Default for SAMPR_ENCRYPTED_USER_PASSWORD {
 }
 impl ::std::fmt::Debug for SAMPR_ENCRYPTED_USER_PASSWORD {
     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-        fmt.debug_struct("SAMPR_ENCRYPTED_USER_PASSWORD")
-            .field("Buffer", &self.Buffer)
-            .finish()
+        fmt.debug_struct("SAMPR_ENCRYPTED_USER_PASSWORD").field("Buffer", &self.Buffer).finish()
     }
 }
 impl ::std::cmp::PartialEq for SAMPR_ENCRYPTED_USER_PASSWORD {
