@@ -1,26 +1,12 @@
-#![allow(
-    unused_variables,
-    non_upper_case_globals,
-    non_snake_case,
-    unused_unsafe,
-    non_camel_case_types,
-    dead_code,
-    clippy::all
-)]
+#![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn AbortSystemShutdownA<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
->(
-    lpmachinename: Param0,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn AbortSystemShutdownA<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>>(lpmachinename: Param0) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn AbortSystemShutdownA(
-                lpmachinename: super::super::Foundation::PSTR,
-            ) -> super::super::Foundation::BOOL;
+            fn AbortSystemShutdownA(lpmachinename: super::super::Foundation::PSTR) -> super::super::Foundation::BOOL;
         }
         ::std::mem::transmute(AbortSystemShutdownA(lpmachinename.into_param().abi()))
     }
@@ -28,19 +14,13 @@ pub unsafe fn AbortSystemShutdownA<
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn AbortSystemShutdownW<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
->(
-    lpmachinename: Param0,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn AbortSystemShutdownW<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>>(lpmachinename: Param0) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn AbortSystemShutdownW(
-                lpmachinename: super::super::Foundation::PWSTR,
-            ) -> super::super::Foundation::BOOL;
+            fn AbortSystemShutdownW(lpmachinename: super::super::Foundation::PWSTR) -> super::super::Foundation::BOOL;
         }
         ::std::mem::transmute(AbortSystemShutdownW(lpmachinename.into_param().abi()))
     }
@@ -48,38 +28,20 @@ pub unsafe fn AbortSystemShutdownW<
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn CheckForHiberboot<
-    'a,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>,
->(
-    phiberboot: *mut super::super::Foundation::BOOLEAN,
-    bclearflag: Param1,
-) -> u32 {
+#[inline]
+pub unsafe fn CheckForHiberboot<'a, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOLEAN>>(phiberboot: *mut super::super::Foundation::BOOLEAN, bclearflag: Param1) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn CheckForHiberboot(
-                phiberboot: *mut super::super::Foundation::BOOLEAN,
-                bclearflag: super::super::Foundation::BOOLEAN,
-            ) -> u32;
+            fn CheckForHiberboot(phiberboot: *mut super::super::Foundation::BOOLEAN, bclearflag: super::super::Foundation::BOOLEAN) -> u32;
         }
-        ::std::mem::transmute(CheckForHiberboot(
-            ::std::mem::transmute(phiberboot),
-            bclearflag.into_param().abi(),
-        ))
+        ::std::mem::transmute(CheckForHiberboot(::std::mem::transmute(phiberboot), bclearflag.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: marker :: Copy,
-    :: std :: clone :: Clone,
-    :: std :: default :: Default,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct EXIT_WINDOWS_FLAGS(pub u32);
 pub const EWX_HYBRID_SHUTDOWN: EXIT_WINDOWS_FLAGS = EXIT_WINDOWS_FLAGS(4194304u32);
@@ -126,142 +88,64 @@ impl ::std::ops::Not for EXIT_WINDOWS_FLAGS {
     }
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn ExitWindowsEx(
-    uflags: EXIT_WINDOWS_FLAGS,
-    dwreason: u32,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn ExitWindowsEx(uflags: EXIT_WINDOWS_FLAGS, dwreason: u32) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn ExitWindowsEx(
-                uflags: EXIT_WINDOWS_FLAGS,
-                dwreason: u32,
-            ) -> super::super::Foundation::BOOL;
+            fn ExitWindowsEx(uflags: EXIT_WINDOWS_FLAGS, dwreason: u32) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(ExitWindowsEx(
-            ::std::mem::transmute(uflags),
-            ::std::mem::transmute(dwreason),
-        ))
+        ::std::mem::transmute(ExitWindowsEx(::std::mem::transmute(uflags), ::std::mem::transmute(dwreason)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateShutdownA<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
->(
-    lpmachinename: Param0,
-    lpmessage: Param1,
-    dwgraceperiod: u32,
-    dwshutdownflags: SHUTDOWN_FLAGS,
-    dwreason: SHUTDOWN_REASON,
-) -> u32 {
+#[inline]
+pub unsafe fn InitiateShutdownA<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>>(lpmachinename: Param0, lpmessage: Param1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateShutdownA(
-                lpmachinename: super::super::Foundation::PSTR,
-                lpmessage: super::super::Foundation::PSTR,
-                dwgraceperiod: u32,
-                dwshutdownflags: SHUTDOWN_FLAGS,
-                dwreason: SHUTDOWN_REASON,
-            ) -> u32;
+            fn InitiateShutdownA(lpmachinename: super::super::Foundation::PSTR, lpmessage: super::super::Foundation::PSTR, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32;
         }
-        ::std::mem::transmute(InitiateShutdownA(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwgraceperiod),
-            ::std::mem::transmute(dwshutdownflags),
-            ::std::mem::transmute(dwreason),
-        ))
+        ::std::mem::transmute(InitiateShutdownA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwgraceperiod), ::std::mem::transmute(dwshutdownflags), ::std::mem::transmute(dwreason)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateShutdownW<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
->(
-    lpmachinename: Param0,
-    lpmessage: Param1,
-    dwgraceperiod: u32,
-    dwshutdownflags: SHUTDOWN_FLAGS,
-    dwreason: SHUTDOWN_REASON,
-) -> u32 {
+#[inline]
+pub unsafe fn InitiateShutdownW<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>>(lpmachinename: Param0, lpmessage: Param1, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32 {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateShutdownW(
-                lpmachinename: super::super::Foundation::PWSTR,
-                lpmessage: super::super::Foundation::PWSTR,
-                dwgraceperiod: u32,
-                dwshutdownflags: SHUTDOWN_FLAGS,
-                dwreason: SHUTDOWN_REASON,
-            ) -> u32;
+            fn InitiateShutdownW(lpmachinename: super::super::Foundation::PWSTR, lpmessage: super::super::Foundation::PWSTR, dwgraceperiod: u32, dwshutdownflags: SHUTDOWN_FLAGS, dwreason: SHUTDOWN_REASON) -> u32;
         }
-        ::std::mem::transmute(InitiateShutdownW(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwgraceperiod),
-            ::std::mem::transmute(dwshutdownflags),
-            ::std::mem::transmute(dwreason),
-        ))
+        ::std::mem::transmute(InitiateShutdownW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwgraceperiod), ::std::mem::transmute(dwshutdownflags), ::std::mem::transmute(dwreason)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateSystemShutdownA<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
-    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
-    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
->(
-    lpmachinename: Param0,
-    lpmessage: Param1,
-    dwtimeout: u32,
-    bforceappsclosed: Param3,
-    brebootaftershutdown: Param4,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn InitiateSystemShutdownA<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>, Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>, Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>>(lpmachinename: Param0, lpmessage: Param1, dwtimeout: u32, bforceappsclosed: Param3, brebootaftershutdown: Param4) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateSystemShutdownA(
-                lpmachinename: super::super::Foundation::PSTR,
-                lpmessage: super::super::Foundation::PSTR,
-                dwtimeout: u32,
-                bforceappsclosed: super::super::Foundation::BOOL,
-                brebootaftershutdown: super::super::Foundation::BOOL,
-            ) -> super::super::Foundation::BOOL;
+            fn InitiateSystemShutdownA(lpmachinename: super::super::Foundation::PSTR, lpmessage: super::super::Foundation::PSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(InitiateSystemShutdownA(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwtimeout),
-            bforceappsclosed.into_param().abi(),
-            brebootaftershutdown.into_param().abi(),
-        ))
+        ::std::mem::transmute(InitiateSystemShutdownA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwtimeout), bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateSystemShutdownExA<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>,
-    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
-    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
->(
+#[inline]
+pub unsafe fn InitiateSystemShutdownExA<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PSTR>, Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>, Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>>(
     lpmachinename: Param0,
     lpmessage: Param1,
     dwtimeout: u32,
@@ -273,35 +157,16 @@ pub unsafe fn InitiateSystemShutdownExA<
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateSystemShutdownExA(
-                lpmachinename: super::super::Foundation::PSTR,
-                lpmessage: super::super::Foundation::PSTR,
-                dwtimeout: u32,
-                bforceappsclosed: super::super::Foundation::BOOL,
-                brebootaftershutdown: super::super::Foundation::BOOL,
-                dwreason: SHUTDOWN_REASON,
-            ) -> super::super::Foundation::BOOL;
+            fn InitiateSystemShutdownExA(lpmachinename: super::super::Foundation::PSTR, lpmessage: super::super::Foundation::PSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(InitiateSystemShutdownExA(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwtimeout),
-            bforceappsclosed.into_param().abi(),
-            brebootaftershutdown.into_param().abi(),
-            ::std::mem::transmute(dwreason),
-        ))
+        ::std::mem::transmute(InitiateSystemShutdownExA(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwtimeout), bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi(), ::std::mem::transmute(dwreason)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateSystemShutdownExW<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
-    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
->(
+#[inline]
+pub unsafe fn InitiateSystemShutdownExW<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>, Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>>(
     lpmachinename: Param0,
     lpmessage: Param1,
     dwtimeout: u32,
@@ -313,65 +178,29 @@ pub unsafe fn InitiateSystemShutdownExW<
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateSystemShutdownExW(
-                lpmachinename: super::super::Foundation::PWSTR,
-                lpmessage: super::super::Foundation::PWSTR,
-                dwtimeout: u32,
-                bforceappsclosed: super::super::Foundation::BOOL,
-                brebootaftershutdown: super::super::Foundation::BOOL,
-                dwreason: SHUTDOWN_REASON,
-            ) -> super::super::Foundation::BOOL;
+            fn InitiateSystemShutdownExW(lpmachinename: super::super::Foundation::PWSTR, lpmessage: super::super::Foundation::PWSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL, dwreason: SHUTDOWN_REASON) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(InitiateSystemShutdownExW(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwtimeout),
-            bforceappsclosed.into_param().abi(),
-            brebootaftershutdown.into_param().abi(),
-            ::std::mem::transmute(dwreason),
-        ))
+        ::std::mem::transmute(InitiateSystemShutdownExW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwtimeout), bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi(), ::std::mem::transmute(dwreason)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn InitiateSystemShutdownW<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
-    Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
-    Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>,
->(
-    lpmachinename: Param0,
-    lpmessage: Param1,
-    dwtimeout: u32,
-    bforceappsclosed: Param3,
-    brebootaftershutdown: Param4,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn InitiateSystemShutdownW<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>, Param3: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>, Param4: ::windows::runtime::IntoParam<'a, super::super::Foundation::BOOL>>(lpmachinename: Param0, lpmessage: Param1, dwtimeout: u32, bforceappsclosed: Param3, brebootaftershutdown: Param4) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn InitiateSystemShutdownW(
-                lpmachinename: super::super::Foundation::PWSTR,
-                lpmessage: super::super::Foundation::PWSTR,
-                dwtimeout: u32,
-                bforceappsclosed: super::super::Foundation::BOOL,
-                brebootaftershutdown: super::super::Foundation::BOOL,
-            ) -> super::super::Foundation::BOOL;
+            fn InitiateSystemShutdownW(lpmachinename: super::super::Foundation::PWSTR, lpmessage: super::super::Foundation::PWSTR, dwtimeout: u32, bforceappsclosed: super::super::Foundation::BOOL, brebootaftershutdown: super::super::Foundation::BOOL) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(InitiateSystemShutdownW(
-            lpmachinename.into_param().abi(),
-            lpmessage.into_param().abi(),
-            ::std::mem::transmute(dwtimeout),
-            bforceappsclosed.into_param().abi(),
-            brebootaftershutdown.into_param().abi(),
-        ))
+        ::std::mem::transmute(InitiateSystemShutdownW(lpmachinename.into_param().abi(), lpmessage.into_param().abi(), ::std::mem::transmute(dwtimeout), bforceappsclosed.into_param().abi(), brebootaftershutdown.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
+#[inline]
 pub unsafe fn LockWorkStation() -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
@@ -393,14 +222,7 @@ pub const POLICY_SHOWREASONUI_ALWAYS: u32 = 1u32;
 pub const POLICY_SHOWREASONUI_NEVER: u32 = 0u32;
 pub const POLICY_SHOWREASONUI_SERVERONLY: u32 = 3u32;
 pub const POLICY_SHOWREASONUI_WORKSTATIONONLY: u32 = 2u32;
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: marker :: Copy,
-    :: std :: clone :: Clone,
-    :: std :: default :: Default,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct SHUTDOWN_FLAGS(pub u32);
 pub const SHUTDOWN_FORCE_OTHERS: SHUTDOWN_FLAGS = SHUTDOWN_FLAGS(1u32);
@@ -457,20 +279,12 @@ impl ::std::ops::Not for SHUTDOWN_FLAGS {
         Self(self.0.not())
     }
 }
-#[derive(
-    :: std :: cmp :: PartialEq,
-    :: std :: cmp :: Eq,
-    :: std :: marker :: Copy,
-    :: std :: clone :: Clone,
-    :: std :: default :: Default,
-    :: std :: fmt :: Debug,
-)]
+#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct SHUTDOWN_REASON(pub u32);
 pub const SHTDN_REASON_NONE: SHUTDOWN_REASON = SHUTDOWN_REASON(0u32);
 pub const SHTDN_REASON_FLAG_COMMENT_REQUIRED: SHUTDOWN_REASON = SHUTDOWN_REASON(16777216u32);
-pub const SHTDN_REASON_FLAG_DIRTY_PROBLEM_ID_REQUIRED: SHUTDOWN_REASON =
-    SHUTDOWN_REASON(33554432u32);
+pub const SHTDN_REASON_FLAG_DIRTY_PROBLEM_ID_REQUIRED: SHUTDOWN_REASON = SHUTDOWN_REASON(33554432u32);
 pub const SHTDN_REASON_FLAG_CLEAN_UI: SHUTDOWN_REASON = SHUTDOWN_REASON(67108864u32);
 pub const SHTDN_REASON_FLAG_DIRTY_UI: SHUTDOWN_REASON = SHUTDOWN_REASON(134217728u32);
 pub const SHTDN_REASON_FLAG_MOBILE_UI_RESERVED: SHUTDOWN_REASON = SHUTDOWN_REASON(268435456u32);
@@ -561,45 +375,27 @@ pub const SNAPSHOT_POLICY_ALWAYS: u32 = 1u32;
 pub const SNAPSHOT_POLICY_NEVER: u32 = 0u32;
 pub const SNAPSHOT_POLICY_UNPLANNED: u32 = 2u32;
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn ShutdownBlockReasonCreate<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>,
-    Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>,
->(
-    hwnd: Param0,
-    pwszreason: Param1,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn ShutdownBlockReasonCreate<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>, Param1: ::windows::runtime::IntoParam<'a, super::super::Foundation::PWSTR>>(hwnd: Param0, pwszreason: Param1) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn ShutdownBlockReasonCreate(
-                hwnd: super::super::Foundation::HWND,
-                pwszreason: super::super::Foundation::PWSTR,
-            ) -> super::super::Foundation::BOOL;
+            fn ShutdownBlockReasonCreate(hwnd: super::super::Foundation::HWND, pwszreason: super::super::Foundation::PWSTR) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(ShutdownBlockReasonCreate(
-            hwnd.into_param().abi(),
-            pwszreason.into_param().abi(),
-        ))
+        ::std::mem::transmute(ShutdownBlockReasonCreate(hwnd.into_param().abi(), pwszreason.into_param().abi()))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn ShutdownBlockReasonDestroy<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>,
->(
-    hwnd: Param0,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn ShutdownBlockReasonDestroy<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>>(hwnd: Param0) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn ShutdownBlockReasonDestroy(
-                hwnd: super::super::Foundation::HWND,
-            ) -> super::super::Foundation::BOOL;
+            fn ShutdownBlockReasonDestroy(hwnd: super::super::Foundation::HWND) -> super::super::Foundation::BOOL;
         }
         ::std::mem::transmute(ShutdownBlockReasonDestroy(hwnd.into_param().abi()))
     }
@@ -607,29 +403,15 @@ pub unsafe fn ShutdownBlockReasonDestroy<
     unimplemented!("Unsupported target OS");
 }
 #[cfg(feature = "Win32_Foundation")]
-pub unsafe fn ShutdownBlockReasonQuery<
-    'a,
-    Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>,
->(
-    hwnd: Param0,
-    pwszbuff: super::super::Foundation::PWSTR,
-    pcchbuff: *mut u32,
-) -> super::super::Foundation::BOOL {
+#[inline]
+pub unsafe fn ShutdownBlockReasonQuery<'a, Param0: ::windows::runtime::IntoParam<'a, super::super::Foundation::HWND>>(hwnd: Param0, pwszbuff: super::super::Foundation::PWSTR, pcchbuff: *mut u32) -> super::super::Foundation::BOOL {
     #[cfg(windows)]
     {
         #[link(name = "windows")]
         extern "system" {
-            fn ShutdownBlockReasonQuery(
-                hwnd: super::super::Foundation::HWND,
-                pwszbuff: super::super::Foundation::PWSTR,
-                pcchbuff: *mut u32,
-            ) -> super::super::Foundation::BOOL;
+            fn ShutdownBlockReasonQuery(hwnd: super::super::Foundation::HWND, pwszbuff: super::super::Foundation::PWSTR, pcchbuff: *mut u32) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(ShutdownBlockReasonQuery(
-            hwnd.into_param().abi(),
-            ::std::mem::transmute(pwszbuff),
-            ::std::mem::transmute(pcchbuff),
-        ))
+        ::std::mem::transmute(ShutdownBlockReasonQuery(hwnd.into_param().abi(), ::std::mem::transmute(pwszbuff), ::std::mem::transmute(pcchbuff)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
