@@ -22,30 +22,17 @@ impl GUID {
 
     /// Creates a `GUID` represented by the all-zero byte-pattern.
     pub const fn zeroed() -> GUID {
-        GUID {
-            data1: 0,
-            data2: 0,
-            data3: 0,
-            data4: [0, 0, 0, 0, 0, 0, 0, 0],
-        }
+        GUID { data1: 0, data2: 0, data3: 0, data4: [0, 0, 0, 0, 0, 0, 0, 0] }
     }
 
     /// Creates a `GUID` with the given constant values.
     pub const fn from_values(data1: u32, data2: u16, data3: u16, data4: [u8; 8]) -> GUID {
-        GUID {
-            data1,
-            data2,
-            data3,
-            data4,
-        }
+        GUID { data1, data2, data3, data4 }
     }
 
     /// Creates a `GUID` for a "generic" WinRT type.
     pub const fn from_signature(signature: ConstBuffer) -> GUID {
-        let data = ConstBuffer::from_slice(&[
-            0x11, 0xf4, 0x7a, 0xd5, 0x7b, 0x73, 0x42, 0xc0, 0xab, 0xae, 0x87, 0x8b, 0x1e, 0x16,
-            0xad, 0xee,
-        ]);
+        let data = ConstBuffer::from_slice(&[0x11, 0xf4, 0x7a, 0xd5, 0x7b, 0x73, 0x42, 0xc0, 0xab, 0xae, 0x87, 0x8b, 0x1e, 0x16, 0xad, 0xee]);
 
         let data = data.push_other(signature);
 
@@ -57,14 +44,7 @@ impl GUID {
         third = (third & 0x0fff) | (5 << 12);
         let fourth = (bytes[8] & 0x3f) | 0x80;
 
-        Self::from_values(
-            first,
-            second,
-            third,
-            [
-                fourth, bytes[9], bytes[10], bytes[11], bytes[12], bytes[13], bytes[14], bytes[15],
-            ],
-        )
+        Self::from_values(first, second, third, [fourth, bytes[9], bytes[10], bytes[11], bytes[12], bytes[13], bytes[14], bytes[15]])
     }
 }
 
@@ -79,21 +59,7 @@ unsafe impl RuntimeType for GUID {
 
 impl std::fmt::Debug for GUID {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(
-            f,
-            "{:08X?}-{:04X?}-{:04X?}-{:02X?}{:02X?}-{:02X?}{:02X?}{:02X?}{:02X?}{:02X?}{:02X?}",
-            self.data1,
-            self.data2,
-            self.data3,
-            self.data4[0],
-            self.data4[1],
-            self.data4[2],
-            self.data4[3],
-            self.data4[4],
-            self.data4[5],
-            self.data4[6],
-            self.data4[7]
-        )
+        write!(f, "{:08X?}-{:04X?}-{:04X?}-{:02X?}{:02X?}-{:02X?}{:02X?}{:02X?}{:02X?}{:02X?}{:02X?}", self.data1, self.data2, self.data3, self.data4[0], self.data4[1], self.data4[2], self.data4[3], self.data4[4], self.data4[5], self.data4[6], self.data4[7])
     }
 }
 
@@ -102,19 +68,11 @@ impl From<&str> for GUID {
         assert!(value.len() == 36, "Invalid GUID string");
         let mut bytes = value.bytes();
 
-        let a = ((bytes.next_u32() * 16 + bytes.next_u32()) << 24)
-            + ((bytes.next_u32() * 16 + bytes.next_u32()) << 16)
-            + ((bytes.next_u32() * 16 + bytes.next_u32()) << 8)
-            + bytes.next_u32() * 16
-            + bytes.next_u32();
+        let a = ((bytes.next_u32() * 16 + bytes.next_u32()) << 24) + ((bytes.next_u32() * 16 + bytes.next_u32()) << 16) + ((bytes.next_u32() * 16 + bytes.next_u32()) << 8) + bytes.next_u32() * 16 + bytes.next_u32();
         assert!(bytes.next().unwrap() == b'-', "Invalid GUID string");
-        let b = ((bytes.next_u16() * 16 + (bytes.next_u16())) << 8)
-            + bytes.next_u16() * 16
-            + bytes.next_u16();
+        let b = ((bytes.next_u16() * 16 + (bytes.next_u16())) << 8) + bytes.next_u16() * 16 + bytes.next_u16();
         assert!(bytes.next().unwrap() == b'-', "Invalid GUID string");
-        let c = ((bytes.next_u16() * 16 + bytes.next_u16()) << 8)
-            + bytes.next_u16() * 16
-            + bytes.next_u16();
+        let c = ((bytes.next_u16() * 16 + bytes.next_u16()) << 8) + bytes.next_u16() * 16 + bytes.next_u16();
         assert!(bytes.next().unwrap() == b'-', "Invalid GUID string");
         let d = bytes.next_u8() * 16 + bytes.next_u8();
         let e = bytes.next_u8() * 16 + bytes.next_u8();
